import Clickoutside from 'element-ui/src/utils/clickoutside'
import { PopupManager } from 'element-ui/src/utils/popup'

export default {
  name: "NbDropdownBoard",
  directives: { Clickoutside },
  props: {
    data: {
      type: Array,
      required: true
    },
    width: String,
    show: {
      type: Object,
      default: {
        value: false
      }
    }
  },
  data () {
    return {
      activeId: null
    }
  },
  methods: {
    isActive(item){
      if(item.path){
        return item.path && item.path == this.$route.path
      }else{
        return item.id == this.activeId
      }
    },
    hide(){
      this.$nextTick(()=>{
        this.show.value = false
      })
    },
    handleClick(item){
      this.activeId = item.id
      this.hide()
      if(item.path){
        this.$router.push(item.path)
      }
      this.$emit('click', item)
    }
  },
  render () {
    return (
      <transition name="fade">
        <div class="nb-dropdown-board" v-clickoutside={()=>{this.hide()}} v-show={this.show.value} style={{width: this.width ? this.width : '100%'}}>
          {
            this._l(this.data, (item, index) =>{
              return (
                <div class={{
                  'nb-dropdown-item': true,
                  'is-active': this.isActive(item)}} 
                  on-click={()=> {this.handleClick(item) }}>{item.text}</div>
              )
            })
          }
        </div>
      </transition>
    )
  },
  mounted(){
    const position = this.$el.parentNode.style.position
    if(!position || position == 'static'){
      this.$el.parentNode.style.position = 'relative'
    }
  },
  watch: {
    show(value, old){
      if(value.value){
        this.$el.style.zIndex = PopupManager.nextZIndex()
      }
    }
  }
}