import { PopupManager } from 'element-ui/src/utils/popup'
const defaults = {
  title: undefined,
  message: '',
  type: '',
  cancelButtonText: '',
  confirmButtonText: '',
  showCancelButton: true,
  showConfirmButton: true
};

import Vue from 'vue';
import msgboxVue from './message-box.vue';

const MessageBoxConstructor = Vue.extend(msgboxVue);

let currentMsg, instance;
let msgQueue = [];

const defaultCallback = action => {

  if (currentMsg) {
    let callback = currentMsg.callback;
    if (typeof callback === 'function') {
      if (instance.showInput) {
        callback(instance.inputValue, action);
      } else {
        callback(action);
      }
    }
    if (currentMsg.resolve) {
      if (action === 'confirm') {
        if (instance.showInput) {
          currentMsg.resolve({ value: instance.inputValue, action });
        } else {
          currentMsg.resolve(action);
        }
      } else if (action === 'cancel' && currentMsg.reject) {
        currentMsg.reject(action);
      }
    }
  }
};

const initInstance = () => {
  instance = new MessageBoxConstructor({
    el: document.createElement('div')
  });

  instance.callback = defaultCallback;
};

const showNextMsg = () => {
  if (!instance) {
    initInstance();
  }
  instance.action = '';

  if (!instance.visible) {
    if (msgQueue.length > 0) {
      currentMsg = msgQueue.shift();

      let options = currentMsg.options;
      for (let prop in options) {
        if (options.hasOwnProperty(prop)) {
          instance[prop] = options[prop];
        }
      }
      if (options.callback === undefined) {
        instance.callback = defaultCallback;
      }

      let oldCb = instance.callback;
      instance.callback = (action, instance) => {
        oldCb(action, instance);
        showNextMsg();
      };
      // if (isVNode(instance.message)) {
      //   instance.$slots.default = [instance.message];
      //   instance.message = null;
      // } else {
      //   delete instance.$slots.default;
      // }
      // ['modal', 'showClose', 'closeOnClickModal', 'closeOnPressEscape', 'closeOnHashChange'].forEach(prop => {
      //   if (instance[prop] === undefined) {
      //     instance[prop] = true;
      //   }
      // });
      // var el = Vue.compile(instance.$el)
      console.log('el', instance.$el);
      //创建遮罩层
      if(document.getElementsByClassName('v-modal').length === 0){
        let dialogModal = document.createElement('div');

        dialogModal.className = 'v-modal dialogModal';
        dialogModal.style.zIndex = PopupManager.nextZIndex();
        document.body.appendChild(dialogModal);
      }
      instance.$el.style.zIndex = PopupManager.nextZIndex()+1000;
      document.body.appendChild(instance.$el);
      Vue.nextTick(() => {
        instance.visible = true;
      });
    }
  }
};

const MessageBox = function(options, callback) {
  if (Vue.prototype.$isServer) return;
  if (options.callback && !callback) {
    callback = options.callback;
  }
  if (typeof Promise !== 'undefined') {
    return new Promise((resolve, reject) => { // eslint-disable-line
      msgQueue.push({
        options: Object.assign({}, defaults, options),
        callback: callback,
        resolve: resolve,
        reject: reject
      });
      showNextMsg();
    });
  } else {
    msgQueue.push({
      options: Object.assign({}, defaults, MessageBox.defaults, options),
      callback: callback
    });
    showNextMsg();
  }
};

MessageBox.confirm = (message, title, options) => {
  if (typeof title === 'object') {
    options = title;
    title = '';success
  } else if (title === undefined) {
    title = '提示';
  }
  return MessageBox(Object.assign({
    title: title,
    message: message,
    $type: 'confirm',
  }, options));
};

export default MessageBox;
export { MessageBox };